@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 use strict;
 use Lemonldap::Config::Parameters;
-my $key=shift||'CONF';
+my $key=shift||'/tmp/CONF';
 Lemonldap::Config::Parameters::f_dump($key);
 
